Package: pharmr
Encoding: UTF-8
Version: 2.1.1
Date: 2026-05-19
Title: Interface to the 'Pharmpy' 'Pharmacometrics' Library
Authors@R: c(
  person("Rikard", "Nordgren", role=c("aut", "cre", "cph"), email="rikard.nordgren@uu.se"),
  person("Stella", "Belin", role=c("aut", "cph"), email="stella.belin@uu.se"),
  person("Mats O.", "Karlsson", role=c("sad")),
  person("Andrew C.", "Hooker", role=c("sad")),
  person("Xiaomei", "Chen", role=c("sad")),
  person("Sebastian", "Ueckert", role=c("sad"), comment=c(ORCID="0000-0002-3712-0255")),
  person("Simon", "Buatois", role=c("rev")),
  person("João A.", "Abrantes", role=c("rev")),
  person("Emilie", "Schindler", role=c("rev")),
  person("F. Hoffmann-La Roche Ltd.", role=c("fnd")),
  person("Bayer AG", role=c("fnd"))
  )
Maintainer: Rikard Nordgren <rikard.nordgren@uu.se>
Depends: R (>= 3.6.0),
SystemRequirements: Python (>= 3.11.0)
Imports: htmltools (>= 0.5.8.1), reticulate (>= 1.38), cli, utils
Suggests: testthat, magrittr, here, knitr
NeedsCompilation: no
Description: Interface to the 'Pharmpy' 'pharmacometrics' library. The 'Reticulate' package is used to interface Python from R.
URL: https://github.com/pharmpy/pharmr
BugReports: https://github.com/pharmpy/pharmr/issues
License: LGPL (>= 3)
Config/roxygen2/version: 8.0.0
Packaged: 2026-05-19 17:11:58 UTC; runner
Author: Rikard Nordgren [aut, cre, cph],
  Stella Belin [aut, cph],
  Mats O. Karlsson [sad],
  Andrew C. Hooker [sad],
  Xiaomei Chen [sad],
  Sebastian Ueckert [sad] (ORCID:
    <https://orcid.org/0000-0002-3712-0255>),
  Simon Buatois [rev],
  João A. Abrantes [rev],
  Emilie Schindler [rev],
  F. Hoffmann-La Roche Ltd. [fnd],
  Bayer AG [fnd]
Repository: CRAN
Date/Publication: 2026-05-28 14:20:02 UTC
Built: R 4.5.2; ; 2026-05-28 15:52:59 UTC; unix
