# Generated by roxygen2: do not edit by hand

S3method(knitr::knit_print,altair.vegalite.v5.api.TopLevelMixin)
S3method(knitr::knit_print,altair.vegalite.v6.api.TopLevelMixin)
S3method(knitr::knit_print,pharmpy.model.distributions.symbolic.JointNormalDistribution)
S3method(knitr::knit_print,pharmpy.model.distributions.symbolic.NormalDistribution)
S3method(knitr::knit_print,pharmpy.model.random_variables.RandomVariables)
S3method(knitr::knit_print,pharmpy.model.statements.Assignment)
S3method(knitr::knit_print,pharmpy.model.statements.Statements)
S3method(knitr::knit_print,pharmpy.modeling.odes.ODEDisplayer)
S3method(length,pharmpy.model.parameters.Parameters)
S3method(print,altair.vegalite.v5.api.TopLevelMixin)
S3method(print,altair.vegalite.v6.api.TopLevelMixin)
S3method(repr::repr_html,pharmpy.model.statements.Statements)
S3method(repr::repr_latex,pharmpy.model.distributions.symbolic.JointNormalDistribution)
S3method(repr::repr_latex,pharmpy.model.distributions.symbolic.NormalDistribution)
S3method(repr::repr_latex,pharmpy.model.random_variables.RandomVariables)
S3method(repr::repr_latex,pharmpy.model.statements.Assignment)
S3method(repr::repr_latex,pharmpy.modeling.odes.ODEDisplayer)
export(add_admid)
export(add_allometry)
export(add_bioavailability)
export(add_cmt)
export(add_covariate_effect)
export(add_derivative)
export(add_effect_compartment)
export(add_estimation_step)
export(add_iiv)
export(add_indirect_effect)
export(add_individual_parameter)
export(add_iov)
export(add_lag_time)
export(add_metabolite)
export(add_output_variables)
export(add_parameter_uncertainty_step)
export(add_pd_iiv)
export(add_peripheral_compartment)
export(add_pk_iiv)
export(add_population_parameter)
export(add_predictions)
export(add_residuals)
export(add_time_after_dose)
export(add_time_of_last_dose)
export(append_estimation_step_options)
export(bin_observations)
export(binarize_dataset)
export(broadcast_log)
export(bump_model_number)
export(calculate_aic)
export(calculate_bic)
export(calculate_corr_from_cov)
export(calculate_corr_from_prec)
export(calculate_cov_from_corrse)
export(calculate_cov_from_prec)
export(calculate_epsilon_gradient_expression)
export(calculate_eta_gradient_expression)
export(calculate_eta_shrinkage)
export(calculate_individual_parameter_statistics)
export(calculate_individual_shrinkage)
export(calculate_parameters_from_ucp)
export(calculate_pk_parameters_statistics)
export(calculate_prec_from_corrse)
export(calculate_prec_from_cov)
export(calculate_se_from_cov)
export(calculate_se_from_prec)
export(calculate_summary_statistic)
export(calculate_ucp_scale)
export(check_dataset)
export(check_high_correlations)
export(check_parameters_near_bounds)
export(check_setup)
export(cholesky_decompose)
export(cleanup_model)
export(convert_model)
export(convert_unit)
export(create_basic_kpd_model)
export(create_basic_pd_model)
export(create_basic_pk_model)
export(create_config_template)
export(create_joint_distribution)
export(create_report)
export(create_rng)
export(create_symbol)
export(deidentify_data)
export(display_odes)
export(drop_columns)
export(drop_dropped_columns)
export(evaluate_epsilon_gradient)
export(evaluate_eta_gradient)
export(evaluate_expression)
export(evaluate_individual_prediction)
export(evaluate_population_prediction)
export(evaluate_weighted_residuals)
export(expand_additional_doses)
export(export_model_files)
export(filter_dataset)
export(find_clearance_parameters)
export(find_volume_parameters)
export(fit)
export(fix_or_unfix_parameters)
export(fix_parameters)
export(fix_parameters_to)
export(get_admid)
export(get_baselines)
export(get_bioavailability)
export(get_central_volume_and_clearance)
export(get_cmt)
export(get_column_name)
export(get_concentration_parameters_from_data)
export(get_config_path)
export(get_covariate_baselines)
export(get_covariate_effects)
export(get_doseid)
export(get_doses)
export(get_dv_symbol)
export(get_evid)
export(get_ids)
export(get_individual_parameters)
export(get_individual_prediction_expression)
export(get_initial_conditions)
export(get_lag_times)
export(get_mdv)
export(get_model_code)
export(get_model_covariates)
export(get_mu_connected_to_parameter)
export(get_nested_model)
export(get_number_of_individuals)
export(get_number_of_observations)
export(get_number_of_observations_per_individual)
export(get_number_of_peripheral_compartments)
export(get_number_of_transit_compartments)
export(get_observation_expression)
export(get_observations)
export(get_omegas)
export(get_parameter_rv)
export(get_pd_parameters)
export(get_pk_parameters)
export(get_population_prediction_expression)
export(get_rv_parameters)
export(get_sigmas)
export(get_thetas)
export(get_unit_of)
export(get_zero_order_inputs)
export(greekify_model)
export(has_additive_error_model)
export(has_combined_error_model)
export(has_covariate_effect)
export(has_first_order_absorption)
export(has_first_order_elimination)
export(has_instantaneous_absorption)
export(has_linear_odes)
export(has_linear_odes_with_real_eigenvalues)
export(has_michaelis_menten_elimination)
export(has_mixed_mm_fo_elimination)
export(has_mu_reference)
export(has_odes)
export(has_presystemic_metabolite)
export(has_proportional_error_model)
export(has_random_effect)
export(has_seq_zo_fo_absorption)
export(has_weibull_absorption)
export(has_weighted_error_model)
export(has_zero_order_absorption)
export(has_zero_order_elimination)
export(infer_datatypes)
export(insert_ebes_into_dataset)
export(install_pharmpy)
export(is_binary)
export(is_linearized)
export(is_real)
export(is_simulation_model)
export(is_strictness_fulfilled)
export(list_models)
export(list_time_varying_covariates)
export(load_dataset)
export(load_example_model)
export(load_example_modelfit_results)
export(make_declarative)
export(map_eta_parameters)
export(mu_reference_model)
export(omit_data)
export(open_context)
export(plot_abs_cwres_vs_ipred)
export(plot_cwres_vs_idv)
export(plot_dv_vs_ipred)
export(plot_dv_vs_pred)
export(plot_eta_distributions)
export(plot_individual_predictions)
export(plot_iofv_vs_iofv)
export(plot_transformed_eta_distributions)
export(plot_vpc)
export(predict_influential_individuals)
export(predict_influential_outliers)
export(predict_outliers)
export(print_fit_summary)
export(print_log)
export(print_model_code)
export(print_model_symbols)
export(print_pharmpy_version)
export(read_dataset_from_datainfo)
export(read_model)
export(read_model_from_string)
export(read_modelfit_results)
export(read_results)
export(remove_bioavailability)
export(remove_covariate_effect)
export(remove_derivative)
export(remove_error_model)
export(remove_estimation_step)
export(remove_iiv)
export(remove_iov)
export(remove_lag_time)
export(remove_loq_data)
export(remove_parameter_uncertainty_step)
export(remove_peripheral_compartment)
export(remove_predictions)
export(remove_residuals)
export(remove_unused_columns)
export(remove_unused_parameters_and_rvs)
export(rename_symbols)
export(replace_fixed_thetas)
export(replace_non_random_rvs)
export(resample_data)
export(reset_index)
export(retrieve_model)
export(retrieve_modelfit_results)
export(retrieve_models)
export(run_allometry)
export(run_amd)
export(run_bootstrap)
export(run_covsearch)
export(run_estmethod)
export(run_iivsearch)
export(run_iovsearch)
export(run_linearize)
export(run_modelfit)
export(run_modelrank)
export(run_modelsearch)
export(run_pdsearch)
export(run_qa)
export(run_retries)
export(run_ruvsearch)
export(run_simulation)
export(run_structsearch)
export(run_tool)
export(run_vpc)
export(sample_individual_estimates)
export(sample_parameters_from_covariance_matrix)
export(sample_parameters_uniformly)
export(set_additive_error_model)
export(set_baseline_effect)
export(set_combined_error_model)
export(set_covariates)
export(set_dataset)
export(set_description)
export(set_direct_effect)
export(set_dtbs_error_model)
export(set_dvid)
export(set_estimation_step)
export(set_evaluation_step)
export(set_first_order_absorption)
export(set_first_order_elimination)
export(set_iiv_on_ruv)
export(set_initial_condition)
export(set_initial_estimates)
export(set_instantaneous_absorption)
export(set_lloq_data)
export(set_lower_bounds)
export(set_michaelis_menten_elimination)
export(set_mixed_mm_fo_elimination)
export(set_n_transit_compartments)
export(set_name)
export(set_ode_solver)
export(set_peripheral_compartments)
export(set_placebo_model)
export(set_power_on_ruv)
export(set_property)
export(set_proportional_error_model)
export(set_reference_values)
export(set_seq_zo_fo_absorption)
export(set_simulation)
export(set_time_varying_error_model)
export(set_tmdd)
export(set_transit_compartments)
export(set_unit)
export(set_upper_bounds)
export(set_weibull_absorption)
export(set_weighted_error_model)
export(set_zero_order_absorption)
export(set_zero_order_elimination)
export(set_zero_order_input)
export(simplify_expression)
export(solve_ode_system)
export(split_joint_distribution)
export(summarize_modelfit_results)
export(transform_blq)
export(transform_etas_boxcox)
export(transform_etas_john_draper)
export(transform_etas_tdist)
export(translate_nmtran_time)
export(unconstrain_parameters)
export(undrop_columns)
export(unfix_parameters)
export(unfix_parameters_to)
export(unload_dataset)
export(update_initial_individual_estimates)
export(use_thetas_for_error_stdev)
export(write_csv)
export(write_dataset)
export(write_model)
export(write_results)
importFrom(reticulate,py_to_r)
importFrom(utils,packageVersion)
