% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{remove_error_model}
\alias{remove_error_model}
\title{remove_error_model}
\usage{
remove_error_model(model)
}
\arguments{
\item{model}{(Model) Pharmpy model}
}
\value{
(Model) Updated Pharmpy model
}
\description{
Remove error model.
}
\examples{
\dontrun{
model <- load_example_model("pheno")
model$statements$find_assignment("Y")
model <- remove_error_model(model)
model$statements$find_assignment("Y")
}

}
