% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{add_indirect_effect}
\alias{add_indirect_effect}
\title{add_indirect_effect}
\usage{
add_indirect_effect(model, expr, prod = TRUE, variable = NULL)
}
\arguments{
\item{model}{(Model) Pharmpy model}

\item{expr}{(str) Production (TRUE) (default) or degradation (FALSE)}

\item{prod}{(logical) Name of PD effect function.}

\item{variable}{(str (optional)) Name of variable to use (if NULL concentration will be used)}
}
\value{
(Model) Updated Pharmpy model
}
\description{
Add indirect (turnover) effect

The concentration (equation could not be rendered, see API doc on website)
\itemize{
\item Production:
}

(equation could not be rendered, see API doc on website)
\itemize{
\item Degradation:
}

(equation could not be rendered, see API doc on website)

(equation could not be rendered, see API doc on website)
Baseline (equation could not be rendered, see API doc on website)

Models:
\itemize{
\item Linear:
}

(equation could not be rendered, see API doc on website)
\itemize{
\item Emax:
}

(equation could not be rendered, see API doc on website)
\itemize{
\item Sigmoidal:
}

(equation could not be rendered, see API doc on website)
}
\examples{
\dontrun{
model <- load_example_model("pheno")
model <- add_indirect_effect(model, expr='linear', prod=TRUE)
}

}
