% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{get_mdv}
\alias{get_mdv}
\title{get_mdv}
\usage{
get_mdv(model)
}
\arguments{
\item{model}{(Model) Pharmpy model}
}
\value{
(data.frame) MDVs
}
\description{
Get MDVs from dataset
}
