% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{print_log}
\alias{print_log}
\title{print_log}
\usage{
print_log(context)
}
\arguments{
\item{context}{(Context) Print the log of this context}
}
\description{
Print the log of a context
}
