% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print_pharmpy_version}
\alias{print_pharmpy_version}
\title{Print pharmpy version}
\usage{
print_pharmpy_version()
}
\description{
Print the pharmpy version pharmr uses.
}
