% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{get_number_of_peripheral_compartments}
\alias{get_number_of_peripheral_compartments}
\title{get_number_of_peripheral_compartments}
\usage{
get_number_of_peripheral_compartments(model)
}
\arguments{
\item{model}{(Model) Pharmpy model}
}
\value{
(integer) Number of peripherals compartments
}
\description{
Return the number of peripherals compartments connected to the central
compartment
}
