% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{has_weighted_error_model}
\alias{has_weighted_error_model}
\title{has_weighted_error_model}
\usage{
has_weighted_error_model(model)
}
\arguments{
\item{model}{(Model) Pharmpy model}
}
\value{
(logical) TRUE if the model has a weighted error model and FALSE otherwise
}
\description{
Check if a model has a weighted error model
}
\examples{
\dontrun{
model <- load_example_model("pheno")
has_weighted_error_model(model)
}
}
\seealso{
has_additive_error_model : Check if a model has an additive error model

has_combined_error_model : Check if a model has a combined error model

has_proportional_error_model : Check if a model has a proportional error model
}
