% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_wrapper.R
\name{has_odes}
\alias{has_odes}
\title{has_odes}
\usage{
has_odes(model)
}
\arguments{
\item{model}{(Model) Pharmpy model}
}
\value{
(logical) TRUE if model has an ODE system
}
\description{
Check if model has an ODE system
}
\examples{
\dontrun{
model <- load_example_model("pheno")
has_odes(model)
}
}
\seealso{
has_linear_odes

has_linear_odes_with_real_eigenvalues
}
